@@ -11,7 +11,7 @@ test_that("Optimizer assertions work", {
   instance = MAKE_INST_2D(terminator = terminator)
   expect_error(optimizer$optimize(instance), "does not support single-crit objectives")
 
-  optimizer = MAKE_OPT(packages = "foo")
+  optimizer = expect_warning(MAKE_OPT(packages = "foo"), "'foo' required but not installed")
   terminator = trm("evals")
   instance = MAKE_INST_2D(terminator = terminator)
   expect_error(optimizer$optimize(instance), class = "packageNotFoundError")
